@@ -1,20 +1,16 @@
 use strict;
 use warnings;
-package Devel::PartialDump;
-{
-  $Devel::PartialDump::VERSION = '0.17';
-}
-# git description: v0.16-10-g3303cfd
-
-BEGIN {
-  $Devel::PartialDump::AUTHORITY = 'cpan:NUFFIN';
-}
+package Devel::PartialDump; # git description: v0.18-5-g7d2520e
+# vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Partial dumping of data structures, optimized for argument printing.
+# KEYWORDS: development debugging dump dumper diagnostics deep data structures
+
+our $VERSION = '0.19';
 
 use Carp ();
 use Scalar::Util qw(looks_like_number reftype blessed);
 
-use namespace::clean;
+use namespace::clean 0.19;
 
 use Class::Tiny {
     max_length => undef,
@@ -36,7 +32,7 @@ use Sub::Exporter -setup => {
     collectors => {
         override_carp => sub {
             no warnings 'redefine';
-            require Carp::Heavy;
+            require Carp;
             *Carp::caller_info = \&replacement_caller_info;
         },
     },
@@ -46,15 +42,7 @@ use Sub::Exporter -setup => {
 sub replacement_caller_info {
     my $i = shift(@_) + 1;
 
-    package DB;
-{
-  $DB::VERSION = '0.17';
-}
-# git description: v0.16-10-g3303cfd
-
-BEGIN {
-  $DB::AUTHORITY = 'cpan:NUFFIN';
-}
+    package DB; # git description: v0.18-5-g7d2520e
     my %call_info;
     @call_info{
     qw(pack file line sub has_args wantarray evaltext is_require)
@@ -333,16 +321,13 @@ __END__
 
 =encoding UTF-8
 
-=for :stopwords יובל קוג'מן (Yuval Kogman) David Steven Lee Golden Florian Ragwitz Jesse
-Luehrs Karen Etheridge Leo Lapworth autodetect Ingy
-
 =head1 NAME
 
 Devel::PartialDump - Partial dumping of data structures, optimized for argument printing.
 
 =head1 VERSION
 
-version 0.17
+version 0.19
 
 =head1 SYNOPSIS
 
@@ -449,6 +434,8 @@ Defaults to false (no overloading).
 
 =item pairs
 
+=for stopwords autodetect
+
 Whether or not to autodetect named args as pairs in the main C<dump> function.
 If this attribute is true, and the top level value list is even sized, and
 every odd element is not a reference, then it will dumped as pairs instead of a
@@ -534,6 +521,8 @@ single element and retain scalar context use
 
 which has a prototype of C<$> (as opposed to taking a list).
 
+=for stopwords Ingy
+
 This is similar to the venerable Ingy's fabulous and amazing L<XXX> module.
 
 =item carp
@@ -598,45 +587,58 @@ has been reached.
 
 =back
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=Devel-PartialDump>
+(or L<bug-Devel-PartialDump@rt.cpan.org|mailto:bug-Devel-PartialDump@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+L<C<#moose> on C<irc.perl.org>|irc://irc.perl.org/#moose>.
+
 =head1 AUTHOR
 
 יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman).
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
+=for stopwords Karen Etheridge Florian Ragwitz Steven Lee Jesse Luehrs David Golden Leo Lapworth
+
 =over 4
 
 =item *
 
-David Golden <dagolden@cpan.org>
-
-=item *
-
-Florian Ragwitz <rafl@debian.org>
-
-=item *
-
-Jesse Luehrs <doy@tozt.net>
-
-=item *
-
 Karen Etheridge <ether@cpan.org>
 
 =item *
 
-Leo Lapworth <web@web-teams-computer.local>
+Florian Ragwitz <rafl@debian.org>
 
 =item *
 
 Steven Lee <stevenwh.lee@gmail.com>
 
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=item *
+
+Leo Lapworth <web@web-teams-computer.local>
+
 =back
 
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
